<?php
/*
 UWiKiCMS is a lightweight web content management system.
 Copyright (C) 2005, 2006, 2007, 2013 Christian Mauduit <ufoot@ufoot.org>

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
 published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public
 License along with this program; if not, write to the Free
 Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA  02110-1301  USA
*/

/*
 * Including stuff from Horde, to use Blowfish. Sadly my
 * provider does not have mcrypt installed so I use this
 * workarround.
 */

$GLOBALS["HORDE_BASE"]=dirname(__FILE__) . DIRECTORY_SEPARATOR . "horde";
define("HORDE_BASE",$GLOBALS["HORDE_BASE"]);

require("horde/lib/Cipher.php");
require("horde/lib/Cipher/blowfish.php");

?>
